@@ -63,7 +63,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat
 );
 
-$VERSION = '0.50.12'; # our $VERSION = '';
+$VERSION = '0.50.20'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. It adopts the block coordinate descent optimization method.';
 
 #################################################################################
@@ -1124,15 +1124,15 @@ sub opt
 	
 		calcoverlaps( @sweeps ); # PRODUCES @calcoverlaps WHICH IS global. ZZZ
 		#say $tee "VARINUMBERS: " . dump ( @varinumbers );
-		@mediumiters = calcmediumiters( @varinumbers ); say $tee "(\@mediumitems): " . dump(@mediumiters); # globsALS. ZZZ
+		@mediumiters = calcmediumiters( @varinumbers ); #say $tee "(\@mediumitems): " . dump(@mediumiters); # globsALS. ZZZ
 		#$itersnum = getitersnum($countcase, $varinumber, @varinumbers); #say "\$itersnum OUT = $itersnum";
 		
-		@rootnames = definerootcases(\@sweeps, \@mediumiters); say $tee "BEGINNING \@rootnames " . dump(@rootnames); 
+		@rootnames = definerootcases(\@sweeps, \@mediumiters); #say $tee "BEGINNING \@rootnames " . dump(@rootnames); 
 		
 		my $countcase = 0;
 		my $countblock = 0;
 
-		my @winneritems = populatewinners( \@rootnames, $countcase, $countblock ); say $tee "BEGINNING \@winneritems " . dump(@winneritems);
+		my @winneritems = populatewinners( \@rootnames, $countcase, $countblock ); #say $tee "BEGINNING \@winneritems " . dump(@winneritems);
 		
 		callcase( { countcase => $countcase, rootnames => \@rootnames, countblock => $countblock, 
 		miditers => \@mediumiters,  winneritems => \@winneritems } );
