@@ -37,7 +37,7 @@ use warnings::unused;
 
 our @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.49.0'; # our $VERSION = '';
+$VERSION = '0.50.20'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -242,7 +242,6 @@ YYY
 ";
 						if ($exeonfiles eq "y")
 						{ 	
-							say "Retrieving temperature results.";
 							say $tee "#Retrieving temperature results.";
 							print `$printthis`;
 						}
@@ -293,8 +292,7 @@ ZZZ
 ";
 						if ($exeonfiles eq "y") 
 						{ 
-							say "Retrieving comfort results.";
-							say TOFILE "#Retrieving comfort results.";
+							say $tee "Retrieving comfort results.";
 							print `$printthis`;
 						}
 						print TOFILE "
@@ -578,7 +576,7 @@ $printthis
 				}
 				
 				#say $tee "\nNow in Sim::OPT::Retrieve. INSIDE";
-				my @resfiles = @{ $simstruct[$countcase][$countblock][$countinstance][$counttool] }; say $tee "SAY\@resfiles " . dump(@resfiles); 
+				my @resfiles = @{ $simstruct[$countcase][$countblock][$countinstance][$counttool] }; #say $tee "SAY\@resfiles " . dump(@resfiles); 
 				#say $tee "SAY\@simcases " . dump( @simcases ); say $tee "SAY\@simstruct " . dump(@simstruct); 
 				
 				#say $tee "\%retrievedata " . dump( %retrievedata );
@@ -596,7 +594,7 @@ $printthis
 							my $reportdata_ref_ref = $reportdata{$counttool}->[$counttheme]; #say $tee "\$reportdata_ref_ref " . dump($reportdata_ref_ref);
 							my @retrievedatarefs = @{$retrievedatum}; #say $tee "\@retrievedatarefs " . dump(@retrievedatarefs);
 							my $simtitle = $simtitles{$counttool}->[ $counttheme ][0]; #say $tee "\$simtitle " . dump($simtitle);
-							my @sims = @{ $simtitles{$counttool}->[ $counttheme ] }[1..4]; say $tee "\@sims " . dump(@sims);
+							my @sims = @{ $simtitles{$counttool}->[ $counttheme ] }[1..4]; #say $tee "\@sims " . dump(@sims);
 							
 							my $resfile = $resfiles[ 0 ]; #say $tee "\HERE\$resfile " . dump($resfile);
 							
@@ -639,7 +637,7 @@ $printthis
 									#		open( RETBLOCK, ">>$retblock"); # or die;
 									#	}
 									#}
-													
+									say $tee "COUNTREPORT! " . dump([$countreport]);				
 									my $reportdata_ref = $reportdata_ref_ref->[$countreport]; #say $tee "\$reportdata_ref" . dump($reportdata_ref); 
 									my @reportdata = @$reportdata_ref;  #say $tee "\@reportdata" . dump(@reportdata); 
 									
@@ -704,7 +702,7 @@ $printthis
 										}
 										elsif ( ( $themereport eq "radent" ) or ( $themereport eq "radabs" ) or ( $themereport eq "airtemp" ) or ( $themereport eq "radtemp" ) or ( $themereport eq "restemp" ) )
 										{ 
-											say $tee "RETRIEVING ADHOC";
+											#say $tee "RETRIEVING ADHOC";
 											retrieve_adhoc( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, 
 														$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ); 
 														#$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines, $adhoclines ); 
@@ -720,82 +718,99 @@ $printthis
 					}
 					elsif ( ( $tooltype eq "generic" ) or ( $tooltype eq "energyplus" ) )
 					{	#use warnings; use strict;
+						#say $tee "USING ENERGYPLUS" ;
 						my @retfiles = @{ $simstruct[$countcase][$countblock][$countinstance][$counttool] }; #say $tee "SAY\@retfiles " . dump(@retfiles); 
 						$retstruct[$countcase][$countblock][$countinstance][$counttool]  = $simstruct[$countcase][$countblock][$countinstance][$counttool] ; 
 						my $counttheme = 0;
 						foreach my $retrievedatum ( @{ $retrievedata{$counttool} } )
 						{
-							my $reportdata_ref_ref = $reportdata{$counttool}->[$counttheme]; #say $tee "\$reportdata_ref_ref " . dump($reportdata_ref_ref);
+							my $reportdata_ref_ref__ = $reportdata{$counttool}; #say $tee "\$reportdata_ref_ref__ " . dump($reportdata_ref_ref__);
 							my @retrievedatarefs = @{$retrievedatum}; #say $tee "\@retrievedatarefs " . dump(@retrievedatarefs);
 							my $simtitle = $simtitles{$counttool}->[ $counttheme ][0]; #say $tee "\$simtitle " . dump($simtitle);
 							my @sims = @{ $simtitles{$counttool}->[ $counttheme ] }[1..4]; #say $tee "\@sims " . dump(@sims);
 							
 							my $resfile = $resfiles[ $counttheme ]; #say $tee "\HERE\$resfile " . dump($resfile);
 							
-							if ( -e $resfile ) 
+							
+							my $countpart = 0;
+							foreach ( @$reportdata_ref_ref__ )
 							{
-								
+								$reportdata_ref_ref = $reportdata{$counttool}->[$countpart];
+							
+							
+							
+								if ( -e $resfile ) 
+								{
+									
 
-								my @retrdata = @$retrievedataref; #say $tee "\@retrdata " . dump(@retrdata);
-				
-								open( RETLIST, ">>$retlist"); # or die;
-								open( RETBLOCK, ">>$retblock"); # or die;
-																				
-								my $reportdata_ref = $reportdata_ref_ref->[$countreport]; #say $tee "\$reportdata_ref" . dump($reportdata_ref); 
-								my @reportdata = @$reportdata_ref;  #say $tee "\@reportdata" . dump(@reportdata); 
-								
-								my $retfile = "$resfile"; #say $tee "\$retfile " . dump($retfile); 
-								if ( not ($retfile ~~ @retcases ) )
-								{
-									push ( @retcases, $retfile );
-									say RETLIST "$retfile";
-								}
-								my @provbag;
-								
-								push ( @provbag, $retfile );
+									my @retrdata = @$retrievedataref; #say $tee "\@retrdata " . dump(@retrdata);
+					
+									open( RETLIST, ">>$retlist"); # or die;
+									open( RETBLOCK, ">>$retblock"); # or die;
+																					
+									my $reportdata_ref = $reportdata_ref_ref->[$countreport]; #say $tee "\$reportdata_ref" . dump($reportdata_ref); 
+									my @reportdata = @$reportdata_ref;  #say $tee "\@reportdata" . dump(@reportdata); 
+									@retcases = uniq( @retcases );
+									my $retfile = "$resfile"; #say $tee "\$retfile " . dump($retfile); 
+									if ( not ($retfile ~~ @retcases ) )
+									{
+										push ( @retcases, $retfile );
+										say RETLIST "$retfile";
+									}
+									my @provbag;
 									
-								my $countitem = 0;
-								foreach my $item ( @reportdata )
-								{
-									my %datarep = %$item; #say $tee "\%datarep" . dump(%datarep); 
-									my $reporttitle = $datarep{reporttitle}; #say $tee "\$reporttitle! " . dump($reporttitle); ###DDD HERE
-									my $themereport = $datarep{themereport}; #say $tee "\$themereport " . dump($themereport); 
-									my $semaphorego1 = $datarep{semaphorego1}; #say $tee "\$semaphorego1 " . dump($semaphorego1); 
-									my $semaphorego2 = $datarep{semaphorego2}; #say $tee "\$semaphorego2 " . dump($semaphorego2); 
-									my $semaphorestop1 = $datarep{semaphorestop1}; #say $tee "\$semaphorestop1 " . dump($semaphorestop1); 
-									my $semaphorestop2 = $datarep{semaphorestop2}; #say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
-									my $textpattern = $datarep{textpattern}; #say $tee "\$textpattern " . dump($textpattern); 
-									my $afterlines = $datarep{afterlines}; #say $tee "\$afterlines " . dump($afterlines);  
-									#say TOFILE "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile);
-									
-									print RETBLOCK "$retfile\n";
-	
-									
-									#if ( not ( $retfile ~~ @provbag ) ) 
-									#{
+									push ( @provbag, $retfile );
 										
-										push ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } , 
-																			{
-																				retfile => $retfile,
-																				reporttitle => $reporttitle,
-																				themereport => $themereport,
-																				semaphorego1 => $semaphorego1,
-																				semaphorego2 => $semaphorego2,
-																				semaphorestop1 => $semaphorestop1,
-																				semaphorestop2 => $semaphorestop2,
-																				textpattern => $textpattern,
-																				afterlines => $afterlines
-																			} );
-									#}
-									$countitem++;
+									my $countitem = 0;
+									foreach my $item ( @reportdata )
+									{
+										my %datarep = %$item; #say $tee "\%datarep" . dump(%datarep); 
+										my $reporttitle = $datarep{reporttitle}; #say $tee "\$reporttitle! " . dump($reporttitle); ###DDD HERE
+										my $themereport = $datarep{themereport}; #say $tee "\$themereport " . dump($themereport); 
+										my $semaphorego1 = $datarep{semaphorego1}; #say $tee "\$semaphorego1 " . dump($semaphorego1); 
+										my $semaphorego2 = $datarep{semaphorego2}; #say $tee "\$semaphorego2 " . dump($semaphorego2); 
+										my $semaphorestop1 = $datarep{semaphorestop1}; #say $tee "\$semaphorestop1 " . dump($semaphorestop1); 
+										my $semaphorestop2 = $datarep{semaphorestop2}; #say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
+										my $textpattern = $datarep{textpattern}; #say $tee "\$textpattern " . dump($textpattern); 
+										my $afterlines = $datarep{afterlines}; #say $tee "\$afterlines " . dump($afterlines);  
+										#say TOFILE "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile);
+										
+										print RETBLOCK "$retfile\n";
+		
+										
+										#if ( not ( $retfile ~~ @provbag ) ) 
+										#{
+											
+											push ( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } , 
+																				{
+																					retfile => $retfile,
+																					reporttitle => $reporttitle,
+																					themereport => $themereport,
+																					semaphorego1 => $semaphorego1,
+																					semaphorego2 => $semaphorego2,
+																					semaphorestop1 => $semaphorestop1,
+																					semaphorestop2 => $semaphorestop2,
+																					textpattern => $textpattern,
+																					afterlines => $afterlines
+																				} );
+										#}
+										$countitem++;
+									}
+
+
 								}
-
-
-							}
-							else  
-							{ 
-								say "A RESULT FILE NAMED $resfile DOES NOT EXIST. EXITING.";
+								else  
+								{ 
+									say "A RESULT FILE NAMED $resfile DOES NOT EXIST. EXITING.";
+								}
+								
+							
+							
+								$countpart++;
 							}
+							
+							
+							
 							$counttheme++;
 						}
 						$counttool++;
@@ -902,10 +917,11 @@ sub report # This function retrieves the results of interest from the texts file
 	my @linecontent;
 	$" = " ";
 	my $repfile;
-	$" = " ";
+	#my @convey;
 	my $countinstance = 0;
-	foreach my $instance (@instances)
+	foreach my $instance ( @instances )
 	{
+		
 		my %d = %{$instance};
 		my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
 		my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
@@ -916,7 +932,6 @@ sub report # This function retrieves the results of interest from the texts file
 		my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
 		my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
 		my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
-		
 		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOFILE "dump(\$rootname): " . dump($rootname);
 		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOFILE "dumpIN( \@blockelts) " . dump(@blockelts);
 		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOFILE "dumpIN( \@blocks) " . dump(@blocks);
@@ -928,7 +943,7 @@ sub report # This function retrieves the results of interest from the texts file
 		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
 		my $varnumber = $countvar; #say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
 
-		say $tee "#Processing reports for case " . ($countcase + 1) . ", block " . ($countblock + 1);
+		say $tee "#Processing reports for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance " . ($countinstance + 1);
 		
 		open( REPLIST, ">>$replist" ) or die( "$!" ); #say TOFILE "dump---(\$replist): " . dump($replist) . "\n\n";  
 		open( REPBLOCK, ">>$repblock" ) or die( "$!" ); #say TOFILE "dump---(\$repblock): " . dump($repblock) . "\n\n";
@@ -943,31 +958,41 @@ sub report # This function retrieves the results of interest from the texts file
 		}
 		
 		open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
+		@repcases = uniq( @repcases );
 		
-		push ( @{ $repstruct[$countcase][$countblock] }, $repfile );
 		say REPBLOCK "$repfile";
 		if ( not ( $repfile ~~ @repcases ) )
 		{
 			push ( @repcases, $repfile );
 			say REPLIST "$repfile";
 		}
-
+		my $signalnewinstance = 1;
+		#if ( not ( $repfile ~~ @{ $repstruct[$countcase][$countblock] } ) )
+		#{
+			#push ( @{ $repstruct[$countcase][$countblock] }, $repfile );
+		#}
+		
 		#open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
 		
-		say $tee "INREPORT dump---(\@notecases): " . dump( @notecases ) . "\n\n";  
+		#say $tee "INREPORT dump---(\@notecases): " . dump( @notecases ) . "\n\n";  
 		
 		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); #say $tee "\$numberof_simtools " . dump( $numberof_simtools );
-		
+		#my @mergestruct;
 		my $counttool = 1;
 		while ( $counttool <= $numberof_simtools )
 		{	
+			#uniq( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } );
 			my $skip = $vals{$countvar}{$counttool}{skip}; #say $tee "dumpinsim(\$skip): " . dump($skip);
 			if ( not ( eval ( $skipsim{$counttool} )))
 			{
 				my $tooltype = $dowhat{simtools}{$counttool}; #say $tee "\$tooltype " . dump( $tooltype );
+				#@{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } = uniq( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] }  );
 				#say $tee "\$notecases[ \$countcase ][ \$countblock ][ \$countinstance ][ \$counttool ] } : " . dump( $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] );
-				foreach $ret_ref ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } )
+				
+				#foreach $ret_ref ( sort { $a->{retfile} <=> $b->{retfile} } ( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ) )
+				foreach $ret_ref ( ( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ) )
 				{
+					
 					#say $tee "INREPORT \$ret_ref " . dump( $ret_ref );
 					%retitem = %$ret_ref; #say $tee "dump---(\@retitem): " . dump(@retitem) . "\n\n";  
 					my $retfile = $retitem{retfile}; #say $tee "dump---(\$retfile): " . dump($retfile) . "\n\n";  
@@ -980,138 +1005,169 @@ sub report # This function retrieves the results of interest from the texts file
 					my $textpattern = $retitem{textpattern}; #say $tee "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
 					my $afterlines = $retitem{afterlines}; #say $tee "INREPORT dump---(\$afterlines): " . dump($afterlines) . "\n\n";  
 					#my $adhoclines = $retitem{adhoclines}; #say $tee "dump---(\$adhoclines): " . dump($adhoclines) . "\n\n";
+					
+					if ( $signalnewinstance == 1 )
+					{
+						push ( @{ $mergestruct[$countcase][$countblock][$countinstance] }, "$retfile " );
+						$signalnewinstance--;
+					}
+					
 					my ( $semaphore1, $semaphore2 );
 					
-					
 					if ( -e $retfile ) #if ( not ( eval ( $skipreport ) ) )
-					{
+					{	say $tee "#Inspecting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance " . ($countinstance + 1) . ", file $retfile, to report $themereport." ;
 						open( RETFILE, "$retfile" ) or die( "$!" );
 						my @lines = <RETFILE>;
 						close RETFILE;
 						#say TOFILE "RETFILE! " ;
 						my $countline = 0;
+						my $signalhit = 0;
+						my $foundhit = 0;
+						my $countlin = 0;
+						my $countli = 0;
 						foreach my $line ( @lines )
 						{
 							$line =~ s/^\s+//;
-							chomp $line;
-							$line = $line . " ";
+							chomp( $line ); 
+							#$line = $line . " ";
 							#say TOFILE "\$line: $line";
 							
-							if ( ( not defined( $semaphorego1 ) ) or ( $line =~ m/$semaphorego1/ ) )
+							if ( ( not ( defined( $semaphorego1 ) ) ) or ( $semaphorego1 eq "" ) or ( $line =~ m/$semaphorego1/ ) )
 							{
-								$semaphore1 = "on";  #say TOFILE "ON1: ";
+								$semaphore1 = "on";  #say $tee "ON1: ";
 							}
 							
 							if ( $semaphore1 eq "on" )
 							{
-								if ( ( not defined( $semaphorego2 ) ) or ( $line =~ m/$semaphorego2/ ) )
+								if ( ( not ( defined( $semaphorego2 ) ) ) or ( $semaphorego2 eq "" ) or ( $line =~ m/$semaphorego2/ ) )
 								{
-									$semaphore2 = "on"; #say TOFILE "ON2: ";
+									$semaphore2 = "on"; #say $tee "ON2: ";
 								}
 							}
 														
-							if ( ( $line =~ m/$semaphorestop1/ ) and ( $semaphorestop1 ne "" ) )
+							if ( ( $line =~ m/$semaphorestop1/ ) and ( defined( $semaphorestop1 ) ) and ( $semaphorestop1 ne "" ) )
 							{
-								$semaphore1 = "off"; #say TOFILE "OFF1: ";
+								$semaphore1 = "off"; #say $tee "OFF1: ";
 							}
 							
-							if ( ( $line =~ m/$semaphorestop2/ ) and ( $semaphorestop2 ne "" ) )
+							if ( ( $line =~ m/$semaphorestop2/ ) and ( defined( $semaphorestop2 ) ) and ( $semaphorestop2 ne "" ) )
 							{
-								$semaphore2 = "off"; #say TOFILE "OFF2: ";
+								$semaphore2 = "off"; #say $tee "OFF2: ";
 							}
+						
+							chomp( $line ); chomp( $line ); 
+							#$line = $line . " ";
 							
-							if ( not ( defined ( $afterlines ) ) )
+							if ( ( not ( defined ( $afterlines ) ) ) or ( $afterlines eq "" ) )
 							{
 								#say $tee "NOT DEFINED AFTERLINES FOR \$themereport $themereport";
 								if ( ( $textpattern ne "" ) and ( $line =~ m/^$textpattern/ ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
-								{
-									#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
-									push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorego1 $semaphorego2 $line " );
-									$semaphore1 = "off";
-									$semaphore2 = "off";
+								{	#print $tee "HIT REPORT1! "; #say TOFILE $line;
+									chomp( $line ); chomp( $line ); 
+									if ( $foundhit == 0 )
+									{	
+										push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport $line " );
+									}
+									else
+									{
+										push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, " $line " );
+									}
+									$foundhit++;
 								}
 							}
 							else
 							{
+								if ( ( $textpattern ne "" ) and ( $line =~ m/^$textpattern/ ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
+								{	#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
+									$signalhit++;
+								}
 								#say $tee "DEFINED AFTERLINES FOR \$themereport $themereport";
-								if ( ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
+								
+								if ( ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) and ( $signalhit > 0 ) )
 								{
 									#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
 									if ( not ( ref( $afterlines ) ) )
 									{	#say $tee "NOT REF BUT DEFINED AFTERLINES FOR \$themereport $themereport";
-										if ( ( $afterlines ne "" ) and ( $countline == $afterlines ) )
-										{
-											#print TOFILE "HIT REPORT2! "; #say TOFILE $line;
-											push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorestop1 $semaphorestop2 $line " );
+										if ( ( $afterlines ne "" ) and ( $countli == $afterlines ) )
+										{	#print TOFILE "HIT REPORT2! "; #say TOFILE $line;
+											chomp( $line ); chomp( $line ); 
+											push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport $line " );
+											$countli++;
 										}
 									}
 									else
 									{	#say $tee "REF AND DEFINED AFTERLINES FOR \$themereport $themereport";
-										my @lins = @$afterlines;  #say $tee "\@lins @lins";
-										my $countlin = 0;
-										foreach my $lin ( @lins )
-										{	#say $tee "FOREACH \$lin: $lin";
-											my $countlocal = 0;
-											unless ( $lin =~ /-/ )
+										my @afterlins = @$afterlines;  #say $tee "\@lins @lins";
+										my @bringer;
+										foreach my $afterlin ( @afterlins )
+										{	#say $tee "FOREACH \$afterlin: $afterlin";
+											if ( not ( $afterlin =~ /-/ ) )
 											{
-												#say $tee "THIS CASE IS ABSENT, ISN'T IT? \$themereport: $themereport";
-												if ( ( $countlocal == 0 ) and ( $countline == $lin ) )
-												{
-													push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorestop1 $semaphorestop2 $line " );
-												}
-												elsif
-												( ( $countlocal > 0 ) and ( $countline == $lin ) )
-												{
-													push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, " $line " );
-												}
-												$countlocal++;
+												push ( @bringer, $afterlin );
 											}
 											else
 											{
-												#say $tee "SPLITTING COUNT FOR REF AND DEFINED AFTERLINES FOR \$themereport $themereport";
-												#my $lin =~ /(.+)-(.+)/ ;
-												#my ( $firstel, $endel ) = ( $1, $2 );
-												my ( $firstel, $endel ) = split( /-/, $lin );
-												
-												my $count = $firstel;
+												my ( $count, $endel ) = split( /-/, $lin );
 												while ( $count <= $endel )
 												{
-													if ( ( $count == $firstel ) and ( $count == $countline ) )
-													{
-														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorestop1 $semaphorestop2 $line " );
-													}
-													elsif ( ( $count > $firstel ) and ( $count == $countline ) )
-													{
-														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, " $line " );
-														if ( $count == $endel )
-														{
-															$countline = 0;
-															$semaphore1 = "off";
-															$semaphore2 = "off";
-														}
-													}
+													push ( @bringer, $count );
 													$count++;
 												}
 											}
-											$countlin++;											
+											
+											my $countlocal = 0;
+											foreach my $afterl ( @bringer )
+											{
+												#say $tee "THIS CASE IS ABSENT, ISN'T IT? \$themereport: $themereport";
+												if ( $countlin == $afterl )
+												{
+													chomp( $line ); chomp( $line ); 
+													if ( $countlocal == 0 )
+													{
+														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport $line " );
+													}
+													else
+													{
+														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, " $line " );
+													}
+												}
+												$counlin++;
+												$countlocal++;
+											}
 										}
 									}
 								}
-							}							
-							
-							if ( ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
-							{
-								$countline++; #say TOFILE "ON3 COUNTLINE: $countline";
 							}
+							$countline++; #say TOFILE "ON3 COUNTLINE: $countline";
 						}
 					}
 					else 
-					{ say $tee "CAN'T FIND NO RES FILE TO OPEN" and die $!; }
+					{ 
+						say $tee "CAN'T FIND NO RES FILE TO OPEN" and die $!; 
+					}
 				}
 			}
 			$counttool++;
 		}
-		#say TOFILE "\@mergestruct: " . dump(@mergestruct); 
+		#say $tee "\@mergestruct: " . dump(@mergestruct); 
+		say $tee "\@{ \$mergestruct[\$countcase][\$countblock][\$countinstance] } : " . dump(@{ $mergestruct[$countcase][$countblock][ $countinstance ] });
+		
+		foreach my $thing ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] } )
+		{
+			$thing =~ s/\n/ /g ; $thing =~ s/\n/ /g ; $thing =~ s/\r/ /g ; $thing =~ s/\r/ /g ;
+			$thing =~ s/\r\n/ /g; $thing =~ s/\r\n/ /g;
+			print REPFILE $thing;
+		}
+		print REPFILE "\n";
+		
+		#my $lin;
+		#foreach my $thing ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] } )
+		#{
+		#	$thing =~ s/\n/ /g ; 
+		#	$lin = $lin . $thing . " ";
+		#}
+		#push ( @{ $convey[ $countcase ][ $counblock ] }, $lin );
+		say "#Reporting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $repfile. ";
 		$countinstance++;
 	}
 	
@@ -1121,17 +1177,11 @@ sub report # This function retrieves the results of interest from the texts file
 	#}
 	#say TOFILE "\@repfilemem ~~ \@mergecases.";
 	
-	say "#Reporting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $repfile. ";
-		
-	foreach my $instref ( @{ $mergestruct[$countcase][$countblock] } )
-	{
-		foreach my $inst ( @$instref )
-		{
-			$inst =~ s/ +/ /g ;
-			print REPFILE "$inst"; #say TOFILE " INSTANCE " . dump($_);
-		}
-		print REPFILE "\n";
-	}
+	#foreach ( sort ( @{ $convey[ $countcase ][ $counblock ] } ) )
+	#{
+		print REPFILE "$_\n"; #say TOFILE " INSTANCE " . dump($_);
+	#}
+	
 	close REPFILE;
 		
 	#say TOFILE "HEREIS \@repcases " . dump(@repcases); say TOFILE "\@repstruct " . dump(@repstruct); say TOFILE "\@mergestruct " . dump(@mergestruct);
