@@ -135,9 +135,9 @@ sub sim    # This function launch the simulations in ESP-r
 	my $descendlist = $dirfiles{descendlist};
 	my $descendblock = $dirfiles{descendblock};
 	
-	my $skipfile = $vals{skipfile}; say TOFILE "dump(\$skipfile): " . dump($skipfile);
-	my $skipsim = $vals{skipsim}; say TOFILE "dump(\$skipsim): " . dump($skipsim);
-	my $skipreport = $vals{skipreport}; say TOFILE "dump(\$skipreport): " . dump($skipreport);
+	my $skipfile = $vals{skipfile}; #say TOFILE "dump(\$skipfile): " . dump($skipfile);
+	my $skipsim = $vals{skipsim}; #say TOFILE "dump(\$skipsim): " . dump($skipsim);
+	my $skipreport = $vals{skipreport}; #say TOFILE "dump(\$skipreport): " . dump($skipreport);
 	
 	#my $getpars = shift;
 	#eval( $getpars );
@@ -464,7 +464,7 @@ $printthis
 						push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] }, $resfile );
 						push ( @{ $retstruct[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] }, $resfile );
 						print SIMBLOCK "$resfile\n";
-					
+						
 						if ( ( not ( $resfile ~~ @retcases ) ) and ( not ( -e $resfile ) ) )
 						{
 							push ( @simcases, $resfile );
